==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/infra/algorithm/type/key-generator/type/uuid/src/main/java/org/apache/shardingsphere/infra/algorithm/keygen/uuid/UUIDKeyGenerateAlgorithm.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.algorithm.keygen.uuid;

import org.apache.shardingsphere.infra.algorithm.keygen.core.KeyGenerateAlgorithm;
import org.apache.shardingsphere.infra.algorithm.core.context.AlgorithmSQLContext;

import java.util.Collection;
import java.util.LinkedList;
import java.util.UUID;
import java.util.concurrent.ThreadLocalRandom;

/**
 * UUID key generate algorithm.
 */
public final class UUIDKeyGenerateAlgorithm implements KeyGenerateAlgorithm {
    
    @Override
    public Collection<String> generateKeys(final AlgorithmSQLContext context, final int keyGenerateCount) {
        Collection<String> result = new LinkedList<>();
        ThreadLocalRandom threadLocalRandom = ThreadLocalRandom.current();
        for (int index = 0; index < keyGenerateCount; index++) {
            result.add(generateKey(threadLocalRandom));
        }
        return result;
    }
    
    private String generateKey(final ThreadLocalRandom threadLocalRandom) {
        return new UUID(threadLocalRandom.nextLong(), threadLocalRandom.nextLong()).toString().replace("-", "");
    }
    
    @Override
    public String getType() {
        return "UUID";
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/infra/algorithm/type/key-generator/type/uuid/src/main/java/org/apache/shardingsphere/infra/algorithm/keygen/uuid/UUIDKeyGenerateAlgorithm.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.algorithm.keygen.uuid;

import org.apache.shardingsphere.infra.algorithm.core.context.AlgorithmSQLContext;
import org.apache.shardingsphere.infra.algorithm.keygen.spi.KeyGenerateAlgorithm;

import java.util.Collection;
import java.util.LinkedList;
import java.util.UUID;
import java.util.concurrent.ThreadLocalRandom;

/**
 * UUID key generate algorithm.
 */
public final class UUIDKeyGenerateAlgorithm implements KeyGenerateAlgorithm {
    
    @Override
    public Collection<String> generateKeys(final AlgorithmSQLContext context, final int keyGenerateCount) {
        Collection<String> result = new LinkedList<>();
        ThreadLocalRandom threadLocalRandom = ThreadLocalRandom.current();
        for (int index = 0; index < keyGenerateCount; index++) {
            result.add(generateKey(threadLocalRandom));
        }
        return result;
    }
    
    private String generateKey(final ThreadLocalRandom threadLocalRandom) {
        return new UUID(threadLocalRandom.nextLong(), threadLocalRandom.nextLong()).toString().replace("-", "");
    }
    
    @Override
    public String getType() {
        return "UUID";
    }
}
